.. _contributors:

Contributors
============

Thank you to the following contributors and others for their invaluble help
and advice in developing OnionBalance. Contributions of any kind (code,
documentation, testing) are very welcome.

* `Federico Ceratto <https://github.com/FedericoCeratto>`_

  - Tireless assistance with Debian packaging and OnionBalance improvements.
  - Replaced and reimplemented the job scheduler.
  - Implemented support for Unix signals and added a status socket to
    retrieve information about the running service.

* `Michael Scherer <https://github.com/mscherer>`_

  - Improving the Debian installation documentation.

* `s7r <https://github.com/gits7r>`_

  - Assisted in testing and load testing OnionBalance from an early stage.
  - Many useful suggestions for performance and usability improvements.
